import { __decorate } from 'tslib';
import { EventEmitter, Output, Input, Component, NgModule } from '@angular/core';
import Swal from 'sweetalert2';
import axios from 'axios';
import { AES } from 'crypto-js';
import * as shajs from 'sha.js';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

let PasswordChangeComponent = class PasswordChangeComponent {
    constructor() {
        this.successModify = new EventEmitter();
        this.name = '';
        this.lname = '';
        this.position = '';
        this.gender = '';
        this.phone = '';
        this.email = '';
        this.area = '';
        this.sector = '';
        this.currentPassword = '';
        this.newPassword = '';
        this.newConfirmPassword = '';
        this.encryptSecretKey = "alexis";
        this.statusPassword = 'No procede';
        this.status = {
            capitalFlag: false,
            numberFlag: false,
            numberPas: false,
        };
    }
    encryptData(data) {
        try {
            return AES.encrypt(JSON.stringify(data), this.encryptSecretKey).toString();
        }
        catch (e) {
            // console.log(e);
        }
    }
    sendModify() {
        const self = this;
        if (this.statusPassword == 'No procede') {
            Swal.fire({
                title: 'Error',
                text: 'Su contraseña no coincide con los criterios requeridos. Verifique e intente nuevamente',
                type: 'error'
            });
        }
        else if (this.newConfirmPassword == this.newPassword) {
            let sentToken = localStorage.getItem("auth-ppa-agrosuper");
            axios({
                method: 'post',
                url: 'https://api-dev.tecnoandina.cl/OAuth/update-data',
                data: {
                    nombre: self.name,
                    apellido: self.lname,
                    cargo: self.position,
                    sexo: self.gender,
                    usuario: self.email,
                    telefono: self.phone,
                    zona: self.area,
                    sector: self.sector,
                    newPassword: shajs('sha256').update(self.newPassword).digest('hex'),
                    oldPassword: shajs('sha256').update(self.currentPassword).digest('hex'),
                },
                headers: {
                    "Authorization": 'Bearer ' + sentToken
                },
                timeout: 30000,
            }).then(function (response) {
                Swal.fire({
                    title: 'Solicitud exitosa',
                    text: 'Sus datos se han modificado correctamente',
                    type: 'success'
                });
                self.successModify.emit({
                    nombre: self.name,
                    apellido: self.lname,
                    cargo: self.position,
                    sexo: self.gender,
                    usuario: self.email,
                    telefono: self.phone,
                    zona: self.area,
                    sector: self.sector
                });
            }).catch(function (error) {
                Swal.fire({
                    title: 'ERROR',
                    text: 'Ocurrió un error al intentar registrar sus datos. Intente nuevamente.',
                    type: 'error'
                });
            });
        }
        else {
            Swal.fire({
                title: 'ERROR',
                text: 'Las contraseñas no coinciden',
                type: 'error'
            });
        }
    }
    colorCheck(prop) {
        if (prop == 'confirmPasswords') {
            if (this.newPassword == this.newConfirmPassword && this.newPassword != '') {
                return 'ppa-check-success pr-2';
            }
            else {
                return 'pr-2';
            }
        }
        else if (this.status[prop] == true) {
            return 'ppa-check-success pr-2';
        }
        else {
            return 'pr-2';
        }
    }
    checkString(val) {
        let ch;
        let i;
        let message;
        this.status = {
            capitalFlag: false,
            numberFlag: false,
            numberPas: false,
        };
        for (i = 0; i < val.length; i++) {
            ch = val.charAt(i);
            if (val.length >= 8) {
                this.status.numberFlag = true;
            }
            if ('A' <= val[i] && val[i] <= 'Z') {
                this.status.capitalFlag = true;
            } // check if you have an uppercase
            if ('0' <= val[i] && val[i] <= '9') {
                this.status.numberPas = true;
            }
            if (this.status.numberPas == true && this.status.numberFlag == true && this.status.capitalFlag == true) {
                this.statusPassword = 'Procede';
                return 'Procede';
            }
            else if (i == (val.length - 1)) {
                this.statusPassword = 'No procede';
                return 'No procede';
            }
        }
    }
    formatInput(v) {
        if (v == true) {
            return 'form-control ppa-input-border ppa-input-with-error';
        }
        else {
            return 'form-control ppa-input-border ';
        }
    }
    setInputs(v, v2) {
        if (v == 'fg1') {
            if (v2 == '') {
                return 'form-group pt-3';
            }
            else {
                return 'form-group pt-3 form-group-valid';
            }
        }
        else if (v == 'fg2') {
            if (v2 == '') {
                return 'form-group';
            }
            else {
                return 'form-group form-group-valid';
            }
        }
        else if (v == 1) {
            if (v2 == '') {
                return 'form-control-placeholder';
            }
            else {
                return 'form-control-placeholder ppa-input-with-text';
            }
        }
        else {
            if (v2 == '') {
                return 'form-control-placeholder';
            }
            else {
                return 'form-control-placeholder ppa-input-with-text';
            }
        }
    }
    ngOnInit() {
        if (this.userData != undefined) {
            this.name = this.userData.nombre;
            this.lname = this.userData.apellido;
            this.position = this.userData.cargo;
            this.phone = this.userData.telefono;
            this.email = this.userData.email;
            this.area = this.userData.zona;
            this.gender = this.userData.sexo;
            this.sector = this.userData.sector;
        }
    }
};
__decorate([
    Output()
], PasswordChangeComponent.prototype, "successModify", void 0);
__decorate([
    Input()
], PasswordChangeComponent.prototype, "userData", void 0);
PasswordChangeComponent = __decorate([
    Component({
        selector: 'ppa-user-data-change',
        template: "<div class=\"card p-3 ppa-change-password-component\">\r\n    <form #formModifyData=\"ngForm\" ngNativeValidate (ngSubmit)=\"sendModify()\" class=\"card-body row\">\r\n        <div class=\"col-12 mb-0\">\r\n            <p class=\"ppa-change-password-title mb-0\">Datos Personales</p></div>\r\n        <div class=\"col-12 col-sm-6 col-md-4\">\r\n            <div [ngClass]=\"setInputs('fg1',name)\">\r\n                <input type=\"text\" id=\"name\" [ngClass]=\"formatInput((nameInput.invalid && (nameInput.dirty || nameInput.touched)))\" name=\"name\" minlength=\"3\" #nameInput=\"ngModel\" [(ngModel)]=\"name\" required>\r\n                <label [ngClass]=\"setInputs(1,name)\" for=\"name\">Nombre</label>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 col-sm-6 col-md-4\">\r\n            <div [ngClass]=\"setInputs('fg1',lname)\">\r\n                <input type=\"text\" id=\"lname\" [ngClass]=\"formatInput((lnameInput.invalid && (lnameInput.dirty || lnameInput.touched)))\" #lnameInput=\"ngModel\" name=\"lname\" minlength=\"3\" [(ngModel)]=\"lname\" required>\r\n                <label [ngClass]=\"setInputs(1,lname)\" for=\"lname\">Apellido</label>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 col-sm-6 col-md-4\">\r\n            <div [ngClass]=\"setInputs('fg1',position)\">\r\n                <select id=\"position\" [ngClass]=\"formatInput((positionInput.invalid && (positionInput.dirty || positionInput.touched)))\" #positionInput=\"ngModel\" name=\"position\" minlength=\"3\" [(ngModel)]=\"position\" required>\r\n                    <option value=\"Gerente General\">Gerente General</option>\r\n                    <option value=\"Gerente General Corporativo\">Gerente General Corporativo</option>\r\n                    <option value=\"Gerente Plantas de Alimento\">Gerente Plantas de Alimento</option>\r\n                    <option value=\"Gerente Producci\u00F3n Animal\">Gerente Producci\u00F3n Animal</option>\r\n                    <option value=\"Gerente Producci\u00F3n Pollos\">Gerente Producci\u00F3n Pollos</option>\r\n                    <option value=\"Gerente Producci\u00F3n Cerdos\">Gerente Producci\u00F3n Cerdos</option>\r\n                    <option value=\"Gerente Producci\u00F3n Pavos\">Gerente Producci\u00F3n Pavos</option>\r\n                    <option value=\"Gerente Transportes\">Gerente Transportes</option>\r\n                    <option value=\"Gerente\">Gerente</option>\r\n                    <option value=\"SubGerente Abuelas y Reproductoras\">SubGerente Abuelas y Reproductoras</option>\r\n                    <option [ngValue]=\"'Subgerente Crianza '\">Subgerente Crianza</option>\r\n                    <option value=\"SubGerente Crianza Broiler\">SubGerente Crianza Broiler</option>\r\n                    <option [ngValue]=\"'Subgerente de Biocorneche '\">Subgerente de Biocorneche</option>\r\n                    <option value=\"Subgerente Engorda Pavos\">Subgerente Engorda Pavos</option>\r\n                    <option value=\"Subgerente Excelencia Operacional\">Subgerente Excelencia Operacional</option>\r\n                    <option value=\"SubGerente Nutrici\u00F3n\">SubGerente Nutrici\u00F3n</option>\r\n                    <option [ngValue]=\"'Subgerente Nutrici\u00F3n y Genetica '\">Subgerente Nutrici\u00F3n y Genetica</option>\r\n                    <option value=\"Subgerente Personas y Administraci\u00F3n\">Subgerente Personas y Administraci\u00F3n</option>\r\n                    <option [ngValue]=\"'Subgerente Proyectos y Mantenci\u00F3n '\">Subgerente Proyectos y Mantenci\u00F3n</option>\r\n                    <option [ngValue]=\"'Subgerente Reproductoras '\">Subgerente Reproductoras</option>\r\n                    <option value=\"Subgerente Reproductoras Pavos\">Subgerente Reproductoras Pavos</option>\r\n                    <option value=\"SubGerente Sanidad\">SubGerente Sanidad</option>\r\n                    <option [ngValue]=\"'Subgerente Sanidad Cerdos '\">Subgerente Sanidad Cerdos</option>\r\n                    <option value=\"Subgerente Sanidad Pavos\">Subgerente Sanidad Pavos</option>\r\n                    <option value=\"Subgerente Sustentabilidad\">Subgerente Sustentabilidad</option> \r\n                    <option value=\"Subgerente T\u00E9cnico Pavos\">Subgerente T\u00E9cnico Pavos</option>\r\n                    <option value=\"Sub-gerente\">Sub-gerente</option>\r\n                    <option [ngValue]=\"'Coordinador Ventilaci\u00F3n '\">Coordinador Ventilaci\u00F3n</option>\r\n                    <option value=\"Jefe Administraci\u00F3n y Gesti\u00F3n\">Jefe Administraci\u00F3n y Gesti\u00F3n</option>\r\n                    <option value=\"Jefe de Admistraci\u00F3n Y Gesti\u00F3n Pavos\">Jefe de Administraci\u00F3n y Gesti\u00F3n Pavos</option>\r\n                    <option value=\"Jefe de crianza\">Jefe de Crianza</option>\r\n                    <option value=\"Jefe de Sector\">Jefe de Sector</option>\r\n                    <option value=\"Jefe de terreno\">Jefe de Terreno</option>\r\n                    <option [ngValue]=\"'Jefe de Transporte de Alimentos '\">Jefe de Transporte de Alimentos</option>\r\n                    <option [ngValue]=\"'Jefe de Transporte Aves '\">Jefe de Transporte Aves</option>\r\n                    <option [ngValue]=\"'Jefe de Transporte Cerdos '\">Jefe de Transporte Cerdos</option>\r\n                    <option value=\"Jefe Incubadora\">Jefe Incubadora</option>\r\n                    <option value=\"Analista Gesti\u00F3n Producci\u00F3n\">Analista Gesti\u00F3n Producci\u00F3n</option>\r\n                    <option [ngValue]=\"'Analista Transporte '\">Analista Transporte</option>\r\n                    <option value=\"Sector\">Sector</option>\r\n                    <option [ngValue]=\"'Trainee Producci\u00F3n '\">Trainee Producci\u00F3n</option>\r\n                    <option value=\"Otro\">Otro</option>\r\n                </select>\r\n                <label [ngClass]=\"setInputs(1,position)\" for=\"position\">Cargo</label>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 col-sm-6 col-md-4\">\r\n            <div [ngClass]=\"setInputs('fg1',gender)\">\r\n                <select id=\"gender\" name=\"gender\" minlength=\"3\" [ngClass]=\"formatInput((genderInput.invalid && (genderInput.dirty || genderInput.touched)))\" #genderInput=\"ngModel\" [(ngModel)]=\"gender\" required>\r\n                    <option value=\"Masculino\">Masculino</option>\r\n                    <option value=\"Femenino\">Femenino</option>\r\n                </select>\r\n                <label [ngClass]=\"setInputs(1,gender)\" for=\"position\">Sexo</label>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 col-sm-6 col-md-4\">\r\n            <div [ngClass]=\"setInputs('fg1',email)\">\r\n                <input type=\"email\" autocomplete=\"off\" id=\"email\" name=\"email\" [ngClass]=\"formatInput((emailInput.invalid && (emailInput.dirty || emailInput.touched)))\" #emailInput=\"ngModel\" [(ngModel)]=\"email\" required>\r\n                <label [ngClass]=\"setInputs(1,email)\" for=\"email\">Correo Electr\u00F3nico</label>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 col-sm-6 col-md-4\">\r\n            <div [ngClass]=\"setInputs('fg1',phone)\">\r\n                <input type=\"text\" id=\"phone\" [ngClass]=\"formatInput((phoneInput.invalid && (phoneInput.dirty || phoneInput.touched)))\" #phoneInput=\"ngModel\" name=\"phone\" pattern=\"[0-9]{9}\" maxlength=\"9\" [(ngModel)]=\"phone\" required>\r\n                <label [ngClass]=\"setInputs(1,phone)\" for=\"phone\">Tel\u00E9fono</label>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 row m-0 p-0\">\r\n            <div class=\"col-12 col-md-8 row m-0 p-0\">\r\n                <div class=\"col-12\">\r\n                    <p class=\"ppa-change-password-title mb-0\">Ubicaci\u00F3n</p>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6\">\r\n                    <div [ngClass]=\"setInputs('fg1',area)\">\r\n                        <select id=\"area\" name=\"area\" (change)=\"sector = ''\" [ngClass]=\"formatInput((areaInput.invalid && (areaInput.dirty || areaInput.touched)))\" #areaInput=\"ngModel\" [(ngModel)]=\"area\" required>\r\n                            <option [ngValue]=\"'Longovilo'\">Longovilo</option>\r\n                            <option [ngValue]=\"'Valdebenito'\">Valdebenito</option>\r\n                            <option [ngValue]=\"'Rancagua'\">Rancagua</option>\r\n                            <option [ngValue]=\"'Estrella'\">Estrella</option>\r\n                            <option [ngValue]=\"'San Francisco'\">San Francisco</option>\r\n                            <option [ngValue]=\"'Oficina Central'\">Oficina Central</option>\r\n                        </select>\r\n                        <label [ngClass]=\"setInputs(1,area)\" for=\"area\">Zona</label>\r\n                    </div>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6\">\r\n                    <div [ngClass]=\"setInputs('fg1',sector)\">\r\n                        <select id=\"sector\" name=\"sector\" [ngClass]=\"formatInput((sectorInput.invalid && (sectorInput.dirty || sectorInput.touched)))\" #sectorInput=\"ngModel\" [(ngModel)]=\"sector\" required minlength=\"3\">\r\n                            <option value=\"\"></option>\r\n                            <option [ngValue]=\"'El Mirador'\" *ngIf=\"area == 'Valdebenito'\">El Mirador</option>\r\n                            <option [ngValue]=\"'Bosque Viejo'\" *ngIf=\"area == 'Rancagua'\">Bosque Viejo</option>\r\n                            <option [ngValue]=\"'La Esmeralda'\" *ngIf=\"area == 'Rancagua'\">La Esmeralda</option>\r\n                            <option [ngValue]=\"'Don Ambrosio'\" *ngIf=\"area == 'Estrella'\">Don Ambrosio</option>\r\n                            <option [ngValue]=\"'Longovilo'\" *ngIf=\"area == 'Longovilo'\">Longovilo</option>\r\n                            <option [ngValue]=\"'Santa Teresa'\" *ngIf=\"area == 'San Francisco'\">Santa Teresa</option>\r\n                            <option [ngValue]=\"'San Pedro'\" *ngIf=\"area == 'San Francisco'\">San Pedro</option>\r\n                            <option [ngValue]=\"'Oficina Central'\" *ngIf=\"area == 'Oficina Central'\">Oficina Central</option>\r\n                        </select>\r\n                        <label [ngClass]=\"setInputs(1,sector)\" for=\"sector\">Sector</label>\r\n                    </div>\r\n                </div>\r\n                <div class=\"col-12\">\r\n                    <p class=\"ppa-change-password-title mb-0\">Seguridad</p>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6 col-lg-4\">\r\n                    <div [ngClass]=\"setInputs('fg1',currentPassword)\" style=\"margin-bottom:0px !important\">\r\n                        <input autocomplete=\"off\" type=\"password\" id=\"currentPassword\" name=\"currentPassword\" minlength=\"8\" [ngClass]=\"formatInput((currentPasswordInput.invalid && (currentPasswordInput.dirty || currentPasswordInput.touched)))\" #currentPasswordInput=\"ngModel\" [(ngModel)]=\"currentPassword\" required>\r\n                        <label [ngClass]=\"setInputs(1,currentPassword)\" for=\"currentPassword\">Contrase\u00F1a Actual</label>\r\n                    </div>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6 col-lg-4\">\r\n                    <div [ngClass]=\"setInputs('fg1',newPassword)\" style=\"margin-bottom:0px !important\">\r\n                        <input autocomplete=\"off\" type=\"password\" (input)=\"checkString(newPassword)\" id=\"newPassword\" class=\"form-control\" name=\"newPassword\" minlength=\"8\" #ngModel [(ngModel)]=\"newPassword\" required>\r\n                        <label [ngClass]=\"setInputs(1,newPassword)\" for=\"newPassword\">Contrase\u00F1a Nueva</label>\r\n                    </div>\r\n                </div>\r\n                <div class=\"col-12 col-sm-6 col-lg-4 mx-auto\">\r\n                    <div [ngClass]=\"setInputs('fg1',newConfirmPassword)\" style=\"margin-bottom:0px !important\">\r\n                        <input autocomplete=\"off\" type=\"password\" id=\"newConfirmPassword\" class=\"form-control\" name=\"newConfirmPassword\" minlength=\"8\" #ngModel [(ngModel)]=\"newConfirmPassword\" required>\r\n                        <label [ngClass]=\"setInputs(1,newConfirmPassword)\" for=\"newConfirmPassword\">Repetir Contrase\u00F1a</label>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n            <div class=\"col-12 col-md-4 d-flex mt-3 mt-md-auto\">\r\n                <div class=\"w-100 card mt-auto mb-0\" style=\"background-color: rgba(131,142,171,.1) !important; border:0 !important\">\r\n                    <div class=\"card-body\">\r\n                        <p class=\"ppa-change-password-title text-justify mb-2\">Su nueva contrase\u00F1a deber\u00E1 cumplir con las siguientes caracter\u00EDsticas:</p>\r\n                        <p><span [ngClass]=\"colorCheck('numberFlag')\"><i class=\"fa fa-check\"></i></span> Deber\u00E1 contener al menos 8 caracteres <br> <span [ngClass]=\"colorCheck('capitalFlag')\"><i class=\"fa fa-check\"></i></span> Tener al menos una mayuscula<br> <span [ngClass]=\"colorCheck('numberPas')\"><i class=\"fa fa-check\"></i></span> Tener al menos un n\u00FAmero<br> <span [ngClass]=\"colorCheck('confirmPasswords')\"><i class=\"fa fa-check\"></i></span> Las dos contrase\u00F1as deben coincidir</p>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12 text-center mt-5\">\r\n            <button type=\"submit\" class=\"btn px-5 py-2\" style=\"border-radius:.5rem !important; background-color: #226BD1; color: white; font-family: 'Mada', sans-serif; font-weight:bold; font-size:18px\">Guardar cambios</button>\r\n        </div>\r\n    </form>\r\n</div>\r\n",
        styles: ["@import url(https://fonts.googleapis.com/css?family=Mada:400,700&display=swap);@import url(https://fonts.googleapis.com/css?family=Open+Sans:400,700&display=swap);@import url(https://use.fontawesome.com/releases/v5.6.3/css/all.css);.ppa-change-password-component{font-family:\"Open Sans\",sans-serif}.ppa-change-password-component p{color:#060606!important}.ppa-input-border{border-radius:.5rem!important}.ppa-change-password-component .ppa-check-success{color:green!important}.ppa-change-password-component .ppa-change-password-title{font-family:Mada,sans-serif!important;font-size:18px!important;font-weight:700}.ppa-change-password-component .form-control-placeholder{position:absolute;top:0;padding:30px 0 0 15px;transition:.2s;opacity:.5}.ppa-change-password-component .form-group-valid .form-control:invalid,.ppa-input-with-error{border:1px solid red!important}.ppa-change-password-component .form-control:-webkit-autofill,.ppa-change-password-component .form-control:-webkit-autofill:focus,.ppa-change-password-component .form-control:-webkit-autofill:hover,.ppa-change-password-component input:-webkit-autofill:active{background:#fff!important;box-shadow:0 0 0 30px #fff inset!important;-webkit-box-shadow:0 0 0 30px #fff inset!important;color:#000!important}.ppa-change-password-component .form-control:focus+.form-control-placeholder,.ppa-change-password-component .form-control:invalid+.ppa-input-with-text,.ppa-change-password-component .form-control:valid+.form-control-placeholder{font-size:14px;transform:translate3d(0,25%,0);opacity:1;margin-left:10px!important;background-color:#fff!important;padding:0 5px!important}.ppa-change-password-component .ppa-input-with-error+.form-control-placeholder{color:red!important}.ppa-change-password-component .form-control{height:50px!important}"]
    })
], PasswordChangeComponent);

let PasswordChangeModule = class PasswordChangeModule {
};
PasswordChangeModule = __decorate([
    NgModule({
        declarations: [PasswordChangeComponent],
        imports: [
            CommonModule,
            FormsModule
        ],
        exports: [PasswordChangeComponent]
    })
], PasswordChangeModule);

/*
 * Public API Surface of password-change
 */

/**
 * Generated bundle index. Do not edit.
 */

export { PasswordChangeModule, PasswordChangeComponent as ɵa };
//# sourceMappingURL=password-change.js.map
